betty.project.extension.demo.copyright_notice module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.project.extension.demo.copyright_notice module

Copyright notices for the Betty demonstration site.

class betty.project.extension.demo.copyright_notice.Streetmix

  Bases: `ShorthandPluginBase`, `CopyrightNotice`

  The copyright for Streetmix resources.

  property summary: Localizable

    The copyright summary.

  property text: Localizable

    The full copyright text.

  property url: Localizable

    The URL to an external human-readable resource with more information about this copyright.